<?php

namespace Drupal\index_now;

use Drupal\Core\DependencyInjection\ClassResolverInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\path_alias\Entity\PathAlias;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Path alias operations class.
 */
class PathAliasOperations implements ContainerInjectionInterface {

  /**
   * Node operations class constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager.
   * @param \Drupal\Core\DependencyInjection\ClassResolverInterface $classResolver
   *   The class resolver service.
   */
  public function __construct(
    protected EntityTypeManagerInterface $entityTypeManager,
    protected ClassResolverInterface $classResolver
  ) {
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('class_resolver')
    );
  }

  /**
   * Ping Index Now for the given path alias.
   *
   * @param \Drupal\path_alias\Entity\PathAlias $path_alias
   *   The path alias we want to ping.
   */
  public function pingIndexNow(PathAlias $path_alias) {
    $exploded_path = explode('/', $path_alias->getPath());
    $entity_type = $exploded_path[1];
    $entity_id = $exploded_path[2];

    if (!in_array($entity_type, ['node', 'taxonomy_term'])) {
      return;
    }

    $entity_storage = $this->entityTypeManager->getStorage($entity_type);
    if (!$entity_storage) {
      return;
    }

    $entity = $entity_storage->load($entity_id);
    if (!$entity) {
      return;
    }

    match ($entity_type) {
      'node' => $this->classResolver->getInstanceFromDefinition(NodeOperations::class)->pingIndexNow($entity),
      'taxonomy_term' => $this->classResolver->getInstanceFromDefinition(TermOperations::class)->pingIndexNow($entity),
    };
  }

}
