<?php

namespace Drupal\Tests\index_now\Unit;

use Drupal\Core\Config\Config;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Logger\LoggerChannelInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\index_now\Service\IndexNow;
use Drupal\index_now\Service\IndexNowKeyManagerInterface;
use Drupal\Tests\UnitTestCase;
use GuzzleHttp\ClientInterface;
use Prophecy\Argument;
use Prophecy\PhpUnit\ProphecyTrait;

/**
 * Tests the IndexNow service.
 *
 * @coversDefaultClass \Drupal\index_now\Service\IndexNow
 *
 * @group index_now
 */
class IndexNowTest extends UnitTestCase {

  use ProphecyTrait;

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();

    $this->client = $this->prophesize(ClientInterface::class);
    $this->configFactory = $this->prophesize(ConfigFactoryInterface::class);
    $this->config = $this->prophesize(Config::class);
    $this->indexNowKeyManager = $this->prophesize(IndexNowKeyManagerInterface::class);
    $this->messenger = $this->prophesize(MessengerInterface::class);
    $this->loggerChannelFactory = $this->prophesize(LoggerChannelFactoryInterface::class);
    $this->logger = $this->prophesize(LoggerChannelInterface::class);

    $this->config
      ->get('default_engine')
      ->willReturn('bing');
    $this->configFactory
      ->getEditable('index_now.settings')
      ->willReturn($this->config->reveal());

    $this->loggerChannelFactory
      ->get('index_now')
      ->willReturn($this->logger->reveal());

    $this->indexNow = new IndexNow(
      $this->client->reveal(),
      $this->configFactory->reveal(),
      $this->indexNowKeyManager->reveal(),
      $this->messenger->reveal(),
      $this->loggerChannelFactory->reveal(),
    );
  }

  /**
   * @covers ::sendRequest
   */
  public function testNoApiKeySendRequest(): void {
    $this->indexNowKeyManager
      ->getKey()
      ->ShouldBeCalled()
      ->willReturn('');

    $page_url = Argument::type('string');
    $this->client->request('GET', $page_url)
      ->shouldNotBeCalled();

    $this->indexNow->sendRequest($page_url);
  }

}
